@@ -79,3 +79,14 @@ class DirectoryDependency(Dependency):
 
     def is_directory(self):
         return True
+
+    def __str__(self):
+        if self.is_root:
+            return self._pretty_name
+
+        return "{} ({} {})".format(
+            self._pretty_name, self._pretty_constraint, self._path
+        )
+
+    def __hash__(self):
+        return hash((self._name, self._full_path))
